# MAMI - Matrix Mixer

A set of modular PCBs that can be used to create a custom configuration for a Matrix Mixer.  A Matrix mixer allows you to mix you any input to any output at the same time.  

<img src="images/final.jpg" height="auto" width="800px">



## What is a matrix mixer?

If you have for example a 4x4 Matrix Mixer, you have 16 knobs with each controlling a how much of a given input signal (`1-4`) will be mixed into a given output (`A-D`):  

<img src="images/4x4-matrix.png" height="auto" width="600px">   

For example by turning up the knob at the intersection between Input `2` and Output `B` we can mix all of the signal present at the input to the output. If we turn up another knob at another intersection, the signal will be present at both outputs:  

<img src="images/matrix-examples.png" height="auto" width="600px">

This makes Matrix mixers extremely flexible and allows for many possible combinations and use cases.


# MAMI-Tiles

The 4x4 matrix in the diagrams above consists of:
- 2x MAMI-INPUT Tiles
- 2x MAMI-OUTPUT Tiles
- 4x MAMI-QUAD Tiles

The tiles are designed in a way they can be connected via wires or jumpers to each other, so multiple configurations are possible (e.g. 2x2, 2x4, 4x2, 8x8, 10x6 etc.).

Here an example 8x8 setup consisting of 4 Input tiles, 4 Output tiles and 16 Tiles:

![Example 8x8 setup consisting of 4 Input modules, 4 Output modules and 16 Tiles](images/8x8_pcbs.png)

## Input Tile [MAMI-INPUT]

The Input Tile has two 3.5mm Mono Input Jacks and two (On)-Off-On Switches that allows muting individual inputs (or momentarily/permanently switching them on). If you want to use another connector (e.g. 6.3mm TS) instead just connect the signals directly to the MAMI-QUAD tiles instead.

| 3D | Dimensions |
| --- | ------ |
| <img src="images/3d-input.png" width="200px"> | <img src="images/board_input.png" height="200px"> |

## 2x2 Quad Tile [MAMI-QUAD]

Mixes two inputs onto two outputs using 4 Potentiometers. The only other parts required are one 0805 resistor for each potentiometer. Note that the choice of value for this resistor will set the maximum gain of the mixer:

The formula to calculate the Gain is:

$$Gain = 20 \cdot \log10{\frac{100 k\Omega}{R1}}$$

| Resistor Value | Maximum Gain |
| -------------- | ------------ |
| 1k | 40dB |
| 10k | 20dB |
| 100k | 0dB |

The 40 dB option should be enough to get consumer line level (e.g. headphone output from consumer devices) to eurorack levels.


| 3D | Dimensions |
| --- | ------ |
| <img src="images/3d-quad.png" width="200px"> | <img src="images/board_quad.png" height="200px"> |


## Output Tile [MAMI-OUTPUT]

Provides two 3.5mm Mono output jacks, with a Jumper (or switch) each row of tiles can be switched between unipolar and bipolar attenuation. Each  output is added to the next channel's output if no jack is plugged in (since rev 1.2). If you don't need normalization don't populate the parts `U3`, `R9`, `R10`, `R11`, `R12`, `R13`, `R14`, `C5` and `C6`

| 3D | Dimensions |
| --- | ---- |
| <img src="images/3d-output.png" height="200px"> | <img src="images/board_out.png" height="200px"> |

The summing section looks like this and allows a jumper (`J_ATT1` and `J_ATT2`) or a switch (2.54mm lead spacing) to be used to switch between unipolar and bipolar attenuation for each row separately.  
<img src="images/schematic_summing.png" height="auto" width="600px">

## Envelope Follower Tile[MAMI-ENV]

A dual Envelope follower that can be hooked up to a `MAMI-OUTPUT`-Tile. Has two output jacks in the same 25mm spacing as the output module and two LEDs that correspond to the output levels.

| 3D | Dimensions |
| --- | --- |
| <img src="images/3d-env.png" height="200px"> | <img src="images/board_env.png" height="200px"> |

# Erata 
### Output Module rev. 1.0 (has been fixed in 1.1)

- Silkscreen for Vee and Vcc is swapped!
- `R4` and `R8` should have a value of 100 Ω not 100 kΩ  (or bridge it with solder)
- Connector `J_W` was flipped by 180° (this however depends on which side you want your outputs). Solve it like this (just make sure the silkscreen labels connect to the right bus): <img src="images/bus-wiring.jpg" height="auto" width="600px">

# Panels

Constructing a panel is straightforward: drill holes for all potentiometers, switches and jacks. 
There are example panels for a 8x8 Matrix (with and without envelope outputs)  in the [panels](panels) directory.

# Parts/BOM

Use the python code in [calculate-parts.ipynb](https://code.hfbk.net/sdiy/mami/blob/master/calculate-parts.ipynb) to calculate the needed parts for your variant of the MAMI

# Power-Supply

The MAMI needs a fitting ±12V Power supply. This obviously depends on the size you are going for and which opamp you use – one Output-Module with 2 channels and a LME49720 draws ~20mA. Anything up to 10x10 should be able to be powered by the [3WPSU](https://code.hfbk.net/sdiy/3wpsu) with a USB-B Phone Charger, as the 3WPSU is able to deliver up to 125mA per rail.
