import csv
import pprint

BOM_IN = "bom/bom.csv"
BOM_OUT = "bom/bom.jlcpcb.csv"

IGNORE_MANUFACTURER = [
    "Song Huei",
    "Bourns",
    "TT Electronics",
    "Wenzhou QingPu Electronics Co.",
    "TE Connectivity",
]

IGNORE_MPN = [
    "Eurorack Powerconnector 2x5 unkeyed white stripe",
    "SSL-LX30FT14IGW LED",
    "Generic Pin header 1×3, 2.54mm pitch, vertical",
    "Generic Pin header 1×5, 2.54mm pitch, vertical",
]

MAP_MPN_TO_LCSC_NO = {
    "LM13700M": "C174050",
    "TL074CPWR": "C96507",
    "TL072CPWR": "C90748",
    "LME49720MAX": "C192421",
    "LM321MF": "C668208",
    "RC0603FR-07100RL": "C327825",
    "CPL-RES-0603-470K-0.1W": "C114622",
    "CPL-RES-0603-220K-0.1W": "C22961",
    "CPL-RES-0603-1.5K-0.1W": "C22843",
    "CPL-RES-0603-47K-0.1W": "C103657",
    "CPL-RES-0603-220-0.1W": "C403073",
    "CPL-RES-0603-1K-0.1W": "C22548",
    "CPL-RES-0603-10K-0.1W": "C98220",
    "CPL-RES-0603-4.7K-0.1W": "C116693",
    "CPL-RES-0603-100K-0.1W": "C115320",
    "RC0603DR-07100KL": "C115320",
    "BC857": "C118733",
    "MMZ2012Y601B": "C76812",
    "NSR0170HT1G": "C139440",
    "LTST-C191KRKT": "C125099",
    "CPL-CAP-X7R-0603-100NF-50V": "C490602",
    "CC0603J_X7R8BB104": "CPL-CAP-X7R-0603-100NF-50V",
    "EEHZA1E101XP": "C127971",
    "C1608C0G1E472J080AA": "C576818",
    "CL10C102JA8NNN": "C519573",
    "CC0603J_X7R8BB474": "C106850",
}

with open(BOM_IN, "r") as f:
    reader = csv.DictReader(f)
    data = [
        row
        for row in reader
        if row["MPN"] not in IGNORE_MPN
        and row["Manufacturer"] not in IGNORE_MANUFACTURER
    ]

new_data = []

for d in data:
    new_item = {}
    new_item["Comment"] = d["Value"].replace("Ω", "").strip()
    new_item["Designator"] = d["Ref. Des."]
    new_item["Footprint"] = d["Package"]
    new_item["JLCPCB Part #（optional）"] = MAP_MPN_TO_LCSC_NO[d["MPN"]]
    new_data.append(new_item)


with open(BOM_OUT, "w") as f:
    w = csv.DictWriter(f, new_data[0].keys())
    w.writeheader()
    w.writerows(new_data)

print(f"Written data to {BOM_OUT}")
bom = data


def find_bom_index_by_refdes(designator):
    for i, row in enumerate(bom):
        rds = [r.strip() for r in row["Ref. Des."].split(",")]
        if designator in rds:
            return i
    return None


PICK_IN = "bom/pick-and-place.top.csv"
PICK_OUT = "bom/pick-and-place.top.jlcpcb.csv"

IGNORE_REFDES = ["T_VOCT", "POWER", "J_ATT1", "J_ATT2", "OUT1", "OUT2", "D1", "D2"]


ROTATE_BY_PACKAGE = {
    "SOT-23-5": 0,
    "SOT-23-3": 180,
    "SOD323": 180,
    "TSSOP-14": 90,
    "TSSOP-8": 0,
    "SOIC-16": 90,
    "SOT-23": 180,
    "SOIC-8": -90,
    "0603 LED": 180,
}

ROTATE_BY_MPN = {"EEHZA1E101XP": -90, "NSR0170HT1G": 180, "LM321MF": 180}

SCALE = 1.0
X_OFFSET = 0.0
Y_OFFSET = 0.0

with open(PICK_IN, "r") as f:
    reader = csv.DictReader(f)
    data = [row for row in reader if row["Designator"] not in IGNORE_REFDES]

for p in data:
    index = find_bom_index_by_refdes(p["Designator"])
    if index is None:
        print(f"Part {p['Designator']} was not found in BOM")
    else:
        # Add the data from the BOM for later filtering
        p["Footprint"] = bom[index]["Package"]
        p["MPN"] = bom[index]["MPN"]
        p["Comment"] = bom[index]["Value"]


new_pnp_data = []

for part in data:
    part["Rotation"] = float(part["Rotation"])
    try:
        x = part["MPN"]
    except KeyError:
        print(f"Part has no MPN: {part}")
    if part["MPN"] in ROTATE_BY_MPN.keys():
        part["Rotation"] += ROTATE_BY_MPN[part["MPN"]]
        part["Rotation"] = part["Rotation"] % 360.0
    elif any([part["Footprint"].startswith(k) for k in ROTATE_BY_PACKAGE.keys()]):
        rotation = float(
            [
                v
                for k, v in ROTATE_BY_PACKAGE.items()
                if part["Footprint"].startswith(k)
            ][0]
        )
        part["Rotation"] += rotation
        part["Rotation"] = part["Rotation"] % 360.0
    # Construct new part, throw away added keys
    new_part = {
        "Designator": part["Designator"],
        "Mid X": float(part["Mid X"]) * SCALE + X_OFFSET,
        "Mid Y": float(part["Mid Y"]) * SCALE + Y_OFFSET,
        "Rotation": part["Rotation"],
        "Layer": part["Layer"],
    }
    new_pnp_data.append(new_part)


with open(PICK_OUT, "w") as f:
    w = csv.DictWriter(f, new_pnp_data[0].keys())
    w.writeheader()
    w.writerows(new_pnp_data)

print(f"Written data to {PICK_OUT}")
